@@ -16,10 +16,11 @@ def layout_css(breakpoint, accent_color, show_laser_pointer = False): # Defult i
             'z-index': '1 !important',
             '^.SingleSlide .Controls': {'display':'none !important',}, 
             '^.CaptureMode': {
-                '.SlideArea .goto-button, .TopBar.Outside': {'display':'none !important'}, # Hide in screenshot
+                '.TopBar.Outside, .SlideArea .goto-button, .Sfresh-Btn': {'visibility':'hidden !important'}, # Hide in screenshot
             },
+            '^.PresentMode .SlideBox .SlideArea .ProxyPasteBtns': {'display':'none !important'}, # Hide in presentation mode
             '^.FullWindow': {
-                '.Height-Dd, .Width-Slider': {'display': 'none !important'},
+                '.Width-Slider': {'display': 'none !important'},
             },
             '^.FullScreen': {
                 '.FullWindow-Btn': {'display': 'none !important'},
@@ -74,6 +75,7 @@ def layout_css(breakpoint, accent_color, show_laser_pointer = False): # Defult i
                 '.report-only': {
                     'display': 'none !important'
                 },
+                '.jp-OutputArea': { 'width': '100% !important', 'box-sizing': 'border-box !important' }, # Otherwise it shrinks small columns
                 _zoom_ables: {'cursor':'zoom-in',},
                 '.Sfresh-Box': {'column-gap': '0.2em',},
                 '.Sfresh-Out': {'width': '100%','box-sizing':'border-box'}, # Otherwise it is too close to border
@@ -131,7 +133,7 @@ def layout_css(breakpoint, accent_color, show_laser_pointer = False): # Defult i
                 },
             },
             '.SidePanel': {
-                'backdrop-filter': 'blur(200px)',
+                'background': 'var(--alternate-bg)',
                 'position': 'absolute',
                 'border': 'none',
                 'padding': '8px !important',
@@ -313,7 +315,8 @@ def layout_css(breakpoint, accent_color, show_laser_pointer = False): # Defult i
         },
         
         '.TOC': { # Table of contents panel
-            'backdrop-filter':' blur(200px)',
+            'background':'var(--secondary-bg)',
+            'backdrop-filter':' blur(50px)',
             'margin':' 4px 36px', 
             'padding':' 0.5em',
             'position':' absolute',
@@ -333,6 +336,7 @@ def layout_css(breakpoint, accent_color, show_laser_pointer = False): # Defult i
                 '^:hover': {'font-weight':'bold',},
             },
             '.goto-button': {
+                'min-width':'max-content',
                 'position': 'absolute',
                 'width': '100%',
                 'height': '100%',
@@ -623,7 +627,7 @@ def layout_css(breakpoint, accent_color, show_laser_pointer = False): # Defult i
                     'background': 'green !important',
                     'font-size': '14px !important', # Avoid this button font scaling
                 },
-                '.Height-Dd, .Width-Slider': {'display': 'none !important',},
+                '.Width-Slider': {'display': 'none !important',}, # do not hide aspect ratio dropdown, that is needed for export
             },
             '.NotesView': {
                 'display': 'none !important', 
@@ -668,7 +672,7 @@ def zoom_hover_css():
             '^:hover, ^:focus': {
                 'cursor': 'auto', # Ovverride zoom-in cursor form main layout
                 'position': 'fixed',
-                'backdrop-filter': 'blur(200px)',
+                'backdrop-filter': 'blur(50px)',
                 'left':'50px',
                 'top':'50px',
                 'z-index':8,
